# web/nodes.py
#
#

""" return all collective nodes """

__copyright__ = 'this file is in the public domain'

from gozerplugs.plugs.webserver import httpd
from gozerplugs.plugs.collective import colls

def handle_nodes(event):
    """ return all collective nodes """
    result = colls.nodesxml()
    if result:
        return [result, ]
    else:
        return []
        
if httpd:
    httpd.addhandler('nodes', handle_nodes)
